searchNodes=[{"doc":"","ref":"Citrine.Job.html","title":"Citrine.Job","type":"module"},{"doc":"Struct that describes a job. Must specify a unique :id, a :schedule using cron syntax, and a task. If :extended_syntax is set to true, the schedule will be parsed as extended cron syntax by Crontab.CronExpression.Parser.Exampleiex(1)&gt; job = %Citrine.Job{ ...(1)&gt; id: &quot;my-job-id&quot;, ...(1)&gt; schedule: &quot;* * * * * *&quot;, ...(1)&gt; task: fn -&gt; nil end, ...(1)&gt; extended_syntax: true ...(1)&gt; }","ref":"Citrine.Job.html#__struct__/0","title":"Citrine.Job.__struct__/0","type":"function"},{"doc":"A unique ID for this job.","ref":"Citrine.Job.html#t:jobid/0","title":"Citrine.Job.jobid/0","type":"type"},{"doc":"Cron-based schedule specification.","ref":"Citrine.Job.html#t:schedule/0","title":"Citrine.Job.schedule/0","type":"type"},{"doc":"","ref":"Citrine.Job.html#t:t/0","title":"Citrine.Job.t/0","type":"type"},{"doc":"The job task to run.","ref":"Citrine.Job.html#t:task/0","title":"Citrine.Job.task/0","type":"type"},{"doc":"The interface for the core Citrine scheduler. To use the scheduler, define a module that uses Citrine.Scheduler.Citrine uses Erlang's :mnesia module for state management. Tables are stored in-memory as RAM copies, thus they are not persisted to disk.UsageDefine a scheduler based on Citrine.Scheduler:defmodule Blogmail.Scheduler do use Citrine.Scheduler, otp_app: :blogmail def initialize_jobs() do # Initialize your jobs here put_job(%Citrine.Job{ id: &quot;hourly&quot;, schedule: &quot;0 * * * *&quot;, task: fn -&gt; nil end }) end endCitrine should be added to your application's supervisor tree:defmodule MyApp.Application do use Application def start(_type, _args) do children = [ # Start the Citrine scheduler MyApp.Scheduler ] opts = [strategy: :one_for_one, name: MyApp.Supervisor] Supervisor.start_link(children, opts) end endAdditionally, it's recommended that you provide an init_task to perform initialization at startup. You should also specify a sufficient init_task_delay to allow everything to settle before running the init task.For example, you could specify the following in config.exs:config :myapp, MyApp.Scheduler, init_task_delay: 30_000, init_task: {MyApp.Scheduler, :initialize_jobs, []}Exampleiex(1)&gt; defmodule MyApp.Scheduler do ...(1)&gt; use Citrine.Scheduler, otp_app: :myapp ...(1)&gt; end iex(2)&gt; MyApp.Scheduler.start_link() iex(3)&gt; MyApp.Scheduler.put_job( ...(3)&gt; %Citrine.Job{ ...(3)&gt; id: &quot;job&quot;, ...(3)&gt; schedule: &quot;* * * * *&quot;, ...(3)&gt; task: fn -&gt; nil end ...(3)&gt; })","ref":"Citrine.Scheduler.html","title":"Citrine.Scheduler","type":"behaviour"},{"doc":"Returns a specification to start this module under a supervisor.See Supervisor.","ref":"Citrine.Scheduler.html#child_spec/1","title":"Citrine.Scheduler.child_spec/1","type":"function"},{"doc":"Returns a count of the number of jobs running on this node in the cluster.","ref":"Citrine.Scheduler.html#c:count_local_jobs/0","title":"Citrine.Scheduler.count_local_jobs/0","type":"callback"},{"doc":"Delete and terminate an existing job matching the specified id.","ref":"Citrine.Scheduler.html#c:delete_job/1","title":"Citrine.Scheduler.delete_job/1","type":"callback"},{"doc":"Retrieve a job by its id.","ref":"Citrine.Scheduler.html#c:get_job/1","title":"Citrine.Scheduler.get_job/1","type":"callback"},{"doc":"Callback implementation for Supervisor.init/1.","ref":"Citrine.Scheduler.html#init/1","title":"Citrine.Scheduler.init/1","type":"function"},{"doc":"List all known jobs in the cluster.","ref":"Citrine.Scheduler.html#c:list_jobs/0","title":"Citrine.Scheduler.list_jobs/0","type":"callback"},{"doc":"Start or update a job. If a job with the same ID already exists, the job will be updated with the new Citrine.Job.","ref":"Citrine.Scheduler.html#c:put_job/1","title":"Citrine.Scheduler.put_job/1","type":"callback"},{"doc":"","ref":"Citrine.Scheduler.html#c:start_link/1","title":"Citrine.Scheduler.start_link/1","type":"callback"},{"doc":"After the scheduler has started, the init task will be executed after :init_task_delay milliseconds have passed.","ref":"Citrine.Scheduler.html#t:init_task/0","title":"Citrine.Scheduler.init_task/0","type":"type"},{"doc":"Delay in milliseconds before executing the :init_task.","ref":"Citrine.Scheduler.html#t:init_task_delay/0","title":"Citrine.Scheduler.init_task_delay/0","type":"type"},{"doc":"","ref":"Citrine.Scheduler.html#t:option/0","title":"Citrine.Scheduler.option/0","type":"type"},{"doc":"","ref":"Citrine.Scheduler.html#t:options/0","title":"Citrine.Scheduler.options/0","type":"type"},{"doc":"","ref":"Citrine.Scheduler.html#t:t/0","title":"Citrine.Scheduler.t/0","type":"opaque"},{"doc":"CitrineCitrine energizes every level of life. It cleanses the chakras and opens the intuition. It's one of the most powerful energy crystals in the world.Citrine is a library for running scheduled jobs on an Erlang cluster, similar to cron. Citrine was created to satisfy a few simple requirements:Provide reliable execution of jobs according to a scheduleKeep jobs running in the event of network splits or other failure scenariosBuild upon Elixir and Erlang primitives with minimum external dependenciesBe easy to operate and reason aboutWork well in stateless container-based environments such as KubernetesDistribute jobs globally across a clusterFollow a pattern of convention over configuration and minimize the number of knobs requiredInternally Citrine uses Erlang's excellent mnesia module for state and process management. It uses in-memory tables, which comes with certain caveats.If you're using mnesia elsewhere in your application, you should be aware that Citrine will attempt to join existing mnesia clusters.","ref":"readme.html","title":"Citrine","type":"extras"},{"doc":"Citrine is not a perfect solution for all scheduling needs. There are certain features Citrine does not implement, or even try to implement, and if you require these features you should either look elsewhere or consider different patterns.Best effort: There are some scenarios in which Citrine could potentially miss execution of a job, such as during a rolling cluster update. Citrine will always try its best to execute jobs according to a schedule, but in some cases it may not.Exactly once semantics: Citrine does not attempt to guarantee a job runs exactly once according to a schedule, it prefers to run jobs multiple times in failure scenarios such as a netsplit.Interruption handling: In the event a job is interrupted during execution, Citrine makes no attempt to restart or re-run the job.Idempotency: This is not so much a limitation but rather a warning: your jobs should be designed to be idempotent to prevent strange side effects. Citrine cannot provide any guarantees.Clustering: Citrine assumes you've already specified the cluster topology, either manually or using a library such as libcluster.If you need stronger guarantees of execution, it's recommended that you use a combination of a stateful queueing service with a worker library, such as Exq.If you're okay with the limitations of the library, Citrine is a great choice due to minimal dependencies and operational burden.","ref":"readme.html#what-citrine-can-and-cannot-do","title":"Citrine - What Citrine can and cannot do","type":"extras"},{"doc":"The package can be installed by adding citrine to your list of dependencies in mix.exs:def deps do [ {:citrine, &quot;~&gt; 0.1.0&quot;} ] end","ref":"readme.html#installation","title":"Citrine - Installation","type":"extras"},{"doc":"Start by creating a module for the core scheduler:defmodule MyApp.Scheduler do use Citrine.Scheduler, otp_app: :myapp endAdd the scheduler to your supervisor tree, for example in application.ex:defmodule MyApp.Application do use Application def start(_type, _args) do children = [ # Start the Citrine scheduler MyApp.Scheduler ] opts = [strategy: :one_for_one, name: MyApp.Supervisor] Supervisor.start_link(children, opts) end endUsing the scheduler:# Create a job job = %Citrine.Job{ id: :my_job_id, schedule: &quot;* * * * * *&quot;, # Run every second task: job_task, extended_syntax: true # Use extended cron syntax } # Start or update a job MyApp.Scheduler.put_job(job) # Terminate and delete a job MyApp.Scheduler.delete_job(job)For further details, see HexDocs.","ref":"readme.html#usage","title":"Citrine - Usage","type":"extras"},{"doc":"Copyright 2020 Brenden Matthews &lt;brenden@brndn.io&gt; Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}]